@@ -4,12 +4,12 @@
 from tg import TGController, tmpl_context
 from tg import config
 
-import moksha.api.widgets
+import moksha.wsgi.widgets.api
 
 __all__ = ['BaseController']
 
 class BaseController(TGController):
     def __call__(self, environ, start_response):
         tmpl_context.moksha_socket = \
-            moksha.api.widgets.get_moksha_socket(config)
+            moksha.wsgi.widgets.api.get_moksha_socket(config)
         return TGController.__call__(self, environ, start_response)
